@@ -18,10 +18,7 @@ limitations under the License.
 
 from __future__ import division, unicode_literals, absolute_import
 
-try:
-    from PySide import QtGui, QtCore, QtGui as QtWidgets
-except ImportError:
-    from PySide2 import QtGui, QtCore, QtWidgets
+from PySide2 import QtGui, QtCore, QtWidgets
 
 import numpy as np
 import pyqtgraph as pg
@@ -166,7 +163,8 @@ class SliceDataView(LogSource):
             # Update data and level for existing contour items, and create new ones if needed
             max_region = max(self._qpdata.regions.keys())
             for val in self._qpdata.regions:
-                pencol = get_col(self._lut, val, (1, max_region))
+                # Contours do not have alpha transparency
+                pencol = get_col(self._lut, val, (1, max_region))[:3]
                 if val != 0:
                     if n_contours == len(self._contours):
                         self._contours.append(pg.IsocurveItem())
@@ -263,8 +261,8 @@ class OrthoSliceViewer(pg.GraphicsView, LogSource):
         # Static labels for the view directions
         self._labels = []
         for axis in [self.xaxis, self.yaxis]:
-            self._labels.append(QtGui.QLabel(ax_labels[axis][0], parent=self))
-            self._labels.append(QtGui.QLabel(ax_labels[axis][1], parent=self))
+            self._labels.append(QtWidgets.QLabel(ax_labels[axis][0], parent=self))
+            self._labels.append(QtWidgets.QLabel(ax_labels[axis][1], parent=self))
         for label in self._labels:
             label.setAttribute(QtCore.Qt.WA_TranslucentBackground)
 
