@@ -22,14 +22,10 @@ import sys
 import tempfile
 import logging
 
-from matplotlib import cm
 import numpy as np
 import pandas as pd
 
-try:
-    from PySide import QtGui, QtCore, QtGui as QtWidgets
-except ImportError:
-    from PySide2 import QtGui, QtCore, QtWidgets
+from PySide2 import QtGui, QtCore, QtWidgets
 
 from quantiphyse.data.extras import DataFrameExtra
 from .exceptions import QpException
@@ -175,7 +171,7 @@ def table_to_extra(tabmod, name):
 
 def copy_table(tabmod):
     """ Copy a QT table model to the clipboard in a form suitable for paste into Excel etc """
-    clipboard = QtGui.QApplication.clipboard()
+    clipboard = QtWidgets.QApplication.clipboard()
     tsv = str(table_to_extra(tabmod, ""))
     clipboard.setText(tsv)
 
