@@ -40,10 +40,7 @@ import six
 import yaml
 import numpy as np
 
-try:
-    from PySide import QtGui, QtCore, QtGui as QtWidgets
-except ImportError:
-    from PySide2 import QtGui, QtCore, QtWidgets
+from PySide2 import QtCore
 
 from quantiphyse.processes import Process
 from quantiphyse.processes.io import *
@@ -201,10 +198,10 @@ class Script(Process):
         if "parsed-yaml" in options:
             root = dict(options.pop("parsed-yaml"))
         elif "yaml" in options:
-            root = yaml.load(options.pop("yaml"))
+            root = yaml.safe_load(options.pop("yaml"))
         elif "yaml-file" in options:
             with open(options.pop("yaml-file"), "r") as yaml_file:
-                root = yaml.load(yaml_file)
+                root = yaml.safe_load(yaml_file)
         else:
             raise RuntimeError("Neither filename nor YAML code provided")
 
@@ -251,11 +248,11 @@ class Script(Process):
         yaml_cases = root.pop("Cases", [])
         if isinstance(yaml_cases, dict):
             for case_id in sorted(yaml_cases.keys()):
-                self._cases.append(Case(case_id, yaml_cases[case_id]))
+                self._cases.append(Case(str(case_id), yaml_cases[case_id]))
         else:
             for case in yaml_cases:
                 case_id = list(case.keys())[0]
-                self._cases.append(Case(case_id, case.get(case_id, {})))
+                self._cases.append(Case(str(case_id), case.get(case_id, {})))
         
         # Create default case if we have not been specified any
         if not self._cases:
